# versioned-hdf5

[![Build
Status](https://travis-ci.org/deshaw/versioned-hdf5.svg?branch=master)](https://travis-ci.org/deshaw/versioned-hdf5)

Versioned HDF5 provides a versioned abstraction on top of `h5py`.

See the documentation at https://deshaw.github.io/versioned-hdf5/.

## History
This was created by the [D. E. Shaw group](https://www.deshaw.com/) in conjunction with [Quansight](https://www.quansight.com/).

<p align="center">
    <a href="https://www.deshaw.com">
       <img src="https://www.deshaw.com/assets/logos/blue_logo_417x125.png" alt="D. E. Shaw Logo" height="75" >
    </a>
</p>

## License
This project is released under a [BSD-3-Clause license](https://github.com/deshaw/versioned-hdf5/blob/master/LICENSE).
